@@ -18,14 +18,16 @@ class Reshape(nn.Module):
         return x.view(self.shape)
 
 
-class GANAttention(nn.Module):
+class GANAttention2d(nn.Module):
     """
-    Custom Attention Module from https://github.com/AdalbertoCq/Pathology-GAN/blob/master/models/generative/ops.py (attention_block)
+    Custom Attention Module inspired by https://github.com/AdalbertoCq/Pathology-GAN/blob/master/models/generative/ops.py (attention_block)
+    
+    GAN related Attention Paper: https://arxiv.org/pdf/1805.08318.pdf
     """
 
     def __init__(self, z: Tuple[int, int, int], channel_divisor: int):
         """
-        Init for GANGAttention
+        Init for GANGAttention2d
 
         :param z: input
         :type tuple(int, int, int): input with format of tuple(channels, width, height)
@@ -33,7 +35,7 @@ class GANAttention(nn.Module):
         :type channel_divisor: int
         """
 
-        super(GANAttention, self).__init__()
+        super(GANAttention2d, self).__init__()
 
         def block_conv_spectral(in_channels, out_channels, kernel_size, stride, padding):
             # Conv + spectral norm
@@ -42,7 +44,6 @@ class GANAttention(nn.Module):
 
         self.channels, self.height, self.width = z
 
-        # TODO is required_grad auto set if it is set for calling class?
         self.gamma = zeros(1)
 
         self.f_g_channels = self.channels//channel_divisor
@@ -60,10 +61,9 @@ class GANAttention(nn.Module):
                                )
 
         # Initiliaze weights
-        self.weights_init()
+        self.init_weights()
 
     def forward(self, x):
-        # it was [batch_size, height*width, channels] in tf
         f_flat = reshape(self.f(x), stack(
             [x.size(0), self.f_g_channels, self.height*self.width]))
         g_flat = reshape(self.g(x), stack(
@@ -82,7 +82,7 @@ class GANAttention(nn.Module):
 
         return y
 
-    def weights_init(self):
+    def init_weights(self):
         for module in self.modules():
             if isinstance(module, nn.Conv2d):
                 nn.init.orthogonal_(module.weight, gain=1e-4)
